==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_results/mp0042_001/MP0042_AddLaborBooking_001_Result.java <==

package net.datastream.schemas.mp_results.mp0042_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.laborbooking_001.LaborBooking;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_entities/LaborBooking_001}LaborBooking"/>
 *                 &lt;/sequence>
 *                 &lt;attribute name="wo_modified" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0042_AddLaborBooking_001_Result")
public class MP0042_AddLaborBooking_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP0042_AddLaborBooking_001_Result.ResultData resultData;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link MP0042_AddLaborBooking_001_Result.ResultData }
     *     
     */
    public MP0042_AddLaborBooking_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link MP0042_AddLaborBooking_001_Result.ResultData }
     *     
     */
    public void setResultData(MP0042_AddLaborBooking_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_entities/LaborBooking_001}LaborBooking"/>
     *       &lt;/sequence>
     *       &lt;attribute name="wo_modified" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "laborBooking"
    })
    public static class ResultData {

        @XmlElement(name = "LaborBooking", namespace = "http://schemas.datastream.net/MP_entities/LaborBooking_001", required = true)
        protected LaborBooking laborBooking;
        @XmlAttribute(name = "wo_modified")
        protected String wo_Modified;

        /**
         * Obtient la valeur de la propriété laborBooking.
         * 
         * @return
         *     possible object is
         *     {@link LaborBooking }
         *     
         */
        public LaborBooking getLaborBooking() {
            return laborBooking;
        }

        /**
         * Définit la valeur de la propriété laborBooking.
         * 
         * @param value
         *     allowed object is
         *     {@link LaborBooking }
         *     
         */
        public void setLaborBooking(LaborBooking value) {
            this.laborBooking = value;
        }

        /**
         * Obtient la valeur de la propriété wo_Modified.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getWo_Modified() {
            return wo_Modified;
        }

        /**
         * Définit la valeur de la propriété wo_Modified.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setWo_Modified(String value) {
            this.wo_Modified = value;
        }

    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_results/mp0042_001/MP0042_AddLaborBooking_001_Result.java <==

package net.datastream.schemas.mp_results.mp0042_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.laborbooking_001.LaborBooking;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_entities/LaborBooking_001}LaborBooking"/>
 *                 &lt;/sequence>
 *                 &lt;attribute name="wo_modified" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0042_AddLaborBooking_001_Result")
public class MP0042_AddLaborBooking_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP0042_AddLaborBooking_001_Result.ResultData resultData;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP0042_AddLaborBooking_001_Result.ResultData }
     *     
     */
    public MP0042_AddLaborBooking_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP0042_AddLaborBooking_001_Result.ResultData }
     *     
     */
    public void setResultData(MP0042_AddLaborBooking_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_entities/LaborBooking_001}LaborBooking"/>
     *       &lt;/sequence>
     *       &lt;attribute name="wo_modified" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "laborBooking"
    })
    public static class ResultData {

        @XmlElement(name = "LaborBooking", namespace = "http://schemas.datastream.net/MP_entities/LaborBooking_001", required = true)
        protected LaborBooking laborBooking;
        @XmlAttribute(name = "wo_modified")
        protected String wo_Modified;

        /**
         * Gets the value of the laborBooking property.
         * 
         * @return
         *     possible object is
         *     {@link LaborBooking }
         *     
         */
        public LaborBooking getLaborBooking() {
            return laborBooking;
        }

        /**
         * Sets the value of the laborBooking property.
         * 
         * @param value
         *     allowed object is
         *     {@link LaborBooking }
         *     
         */
        public void setLaborBooking(LaborBooking value) {
            this.laborBooking = value;
        }

        /**
         * Gets the value of the wo_Modified property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getWo_Modified() {
            return wo_Modified;
        }

        /**
         * Sets the value of the wo_Modified property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setWo_Modified(String value) {
            this.wo_Modified = value;
        }

    }

}
